@@ -5,10 +5,11 @@
 # @author       Rick Kennell <kennell@purdue.edu>
 # @author       Pascal Meunier <pmeunier@purdue.edu>
 # @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
-# @copyright    Copyright (c) 2005-2013 HUBzero Foundation, LLC.
+# @author       David Benham <dbenham@purdue.edu>
+# @copyright    Copyright (c) 2005-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2005-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2005-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -217,7 +218,16 @@ def daemonize():
 def change_www():
   if os.getuid() == 0:
     try:
-      _, _, uid, gid, _, _, _ = pwd.getpwnam("www-data")
+
+      if os.path.exists("/etc/debian_version"):
+        wwwuser='www-data'
+      elif os.path.exists("/etc/redhat-release"):
+        wwwuser='apache'
+      else:
+        print "unknown web user, cannot determine distribution"
+        exit(1)
+
+      _, _, uid, gid, _, _, _ = pwd.getpwnam(wwwuser)
       os.setregid(gid, gid)
       os.setreuid(uid, uid)
     except OSError:
